import { ShaderGlobalData } from '../types/CommonType';
/**
 * This class resolves the created node graph and creates vertex and fragment shaders.
 */
export default class ShaderGraphResolver {
    /**
     * Create vertex and fragment shaderity objects from nodes
     * @param vertexShaderGlobalData Defining define directives and constant values and
     *                               specifying precision for use in vertex shader
     * @param fragmentShaderGlobalData Defining define directives and constant values and
     *                                 specifying precision for use in fragment shader
     * @returns shaderity objects of shaders
     */
    static createShaderityObjects(vertexShaderGlobalData?: ShaderGlobalData, fragmentShaderGlobalData?: ShaderGlobalData): {
        vertexShaderityObject: import("shaderity/dist/esm/types/type").ShaderityObject;
        fragmentShaderityObject: import("shaderity/dist/esm/types/type").ShaderityObject;
    };
    /**
     * @private
     * Create vertex or fragment shaderity object from nodes
     * @param sortedNodes Topologically sorted nodes used in the shader to be created.
     * @param shaderStage Specify vertex of fragment shader
     * @param globalData Defining define directives and constant values and
     *                   specifying precision for use in the shader
     * @returns shaderity object
     */
    private static __createShaderityObject;
    /**
     * @private
     * Set globalData to shaderityObjectCreator
     * @param shaderityObjectCreator shaderityObjectCreator object of shaderity
     * @param globalData Defining define directives and constant values and
     *                   specifying precision for use in the shader
     */
    private static __addGlobalDataToShaderityObjectCreator;
    /**
     * @private
     * Set data of a node to shaderityObjectCreator
     * This supports declaration of attribute, varying and uniform variables and
     * definition of extensions and functions in shader
     * @param shaderityObjectCreator shaderityObjectCreator object of shaderity
     * @param node target node
     * @param shaderFunctionDataKeys array to prevent duplicate function definitions in shader
     * @param shaderStage  Specify vertex of fragment shader
     */
    private static __addNodeDataToShaderityObjectCreator;
    /**
     * @private
     * Create the main function by arranging the function calls in the order of index in the array
     * @param sortedNodes topologically sorted array of nodes
     * @returns shader code of main function
     */
    private static __createMainFunctionCode;
    /**
     * @private
     * Initialize an array to store the variable names to be used in each function call of the main function
     * @param nodes array of nodes
     * @returns array to store the variable names
     */
    private static __initializeArgumentNameListOfFunctionsCalledInMainFunction;
    /**
     * @private
     * Create a string of variable definitions corresponding to the standard input socket
     * that is not connected to the output socket.
     * The created variable is initialized with the default value of the socket.
     *
     * The names of created variables are stored in the argumentNameList at the position of the corresponding
     * input socket.
     * @param node target node
     * @param argumentNameList array to store the variable names used in each function call of the main function
     * @returns string of variable definitions
     */
    private static __createInputVariableDefinitionsAndStoreVariableName;
    /**
     * @private
     * Create string of variable declarations for each output socket.
     *
     * The name of the created variable is stored in the argumentNameList at the position of the corresponding
     * output socket and the connected input sockets.
     * @param node target node
     * @param argumentNameList array to store the variable names used in each function call of the main function
     * @returns string of variable declarations
     */
    private static __createOutVariableDeclarationsAndStoreVariableName;
    /**
     * @private
     * Set the attribute/varying/uniform variable name to argumentNameList to the corresponding position in the socket
     * @param node target node
     * @param argumentNameList array to store the variable names used in each function call of the main function
     */
    private static __addStorageQualifierVariableName;
    private static __addShaderOutputVariableName;
    /**
     * @private
     * Create a function call string based on the argumentNameList and the functionName of target node
     * @param node target node
     * @param argumentNameList array to store the variable names used in each function call of the main function
     * @returns function call string
     */
    private static __createShaderGraphFunctionCalls;
}
