import AbstractSocket from '../abstract/AbstractSocket';
import { INode } from '../../node/INode';
import { ShaderAttributeData } from '../../types/CommonType';
/**
 * The AttributeInputSocket is an input socket that receives an attribute variable.
 * If the function corresponding to a node uses an attribute variable,
 * the function must use this socket to receive the variable as an argument.
 * This socket can be used only with vertex shader nodes.
 */
export default class AttributeInputSocket extends AbstractSocket {
    private __variableName;
    private __type;
    private __precision?;
    private __location;
    constructor(node: INode, socketName: string, attribute: ShaderAttributeData);
    /**
     * Get the class name of this socket
     */
    get className(): 'AttributeInputSocket';
    /**
     * Get the attribute variable name
     */
    get variableName(): string;
    /**
     * Get the glsl type of attribute variable
     */
    get socketType(): import("shaderity/dist/esm/types/type").ShaderAttributeVarType;
    /**
     * Get the precision of attribute variable
     */
    get precision(): import("shaderity/dist/esm/types/type").ShaderPrecisionType | undefined;
    /**
     * Get the location of attribute variable(for GLSL ES3.0)
     */
    get location(): number | undefined;
}
