import { SamplerTypeEnum } from '../../types/CommonEnum';
import { INode } from '../../node/INode';
import AbstractSocket from '../abstract/AbstractSocket';
import { ISamplerInputSocket } from '../interface/input/ISamplerInputSocket';
import { ISamplerOutputSocket } from '../interface/output/ISamplerOutputSocket';
/**
 * The SamplerInputSocket is an input socket that can connect to a SamplerOutputSocket.
 * This socket can connect to at most one SamplerOutputSocket.
 */
export default class SamplerInputSocket extends AbstractSocket implements ISamplerInputSocket {
    private __connectedSocket;
    private __socketType;
    constructor(node: INode, socketName: string, type: SamplerTypeEnum);
    /**
     * Get the class name of this socket
     */
    get className(): 'SamplerInputSocket';
    /**
     * Get the glsl type of data to be passed between sockets
     */
    get socketType(): SamplerTypeEnum;
    /**
     * Get the node that has the socket connected to this socket
     * @returns connected node or undefined
     */
    get connectedNode(): INode | undefined;
    /**
     * Get the socket that is connected to this socket
     * @returns connected socket or undefined
     */
    get connectedSocket(): ISamplerOutputSocket | undefined;
    /**
     * Get the uniform variable name of the connected sampler node
     */
    get variableName(): string;
    /**
     * Get the precision of uniform variable of the connected sampler node
     */
    get precision(): import("shaderity/dist/esm/types/type").ShaderPrecisionType | undefined;
    /**
     * Connect this socket and a Sampler output socket
     * @param outputSocket The output socket to connect to
     */
    connectSocketWith(outputSocket: ISamplerOutputSocket): void;
}
