import { IStandardInputSocket } from '../interface/input/IStandardInputSocket';
import { IStandardOutputSocket } from '../interface/output/IStandardOutputSocket';
import { INode } from '../../node/INode';
import { ShaderStandardInputData } from '../../types/CommonType';
import { SocketTypeEnum } from '../../types/CommonEnum';
import AbstractSocket from '../abstract/AbstractSocket';
/**
 * The StandardInputSocket is an input socket that can connect to a StandardOutputSocket.
 * This socket can connect to at most one StandardOutputSocket.
 */
export default class StandardInputSocket extends AbstractSocket implements IStandardInputSocket {
    private __socketType;
    /**
     * @private
     * If this socket does not connect with output socket,
     * the __defaultValue is used as input value.
     */
    private __defaultValue;
    private __connectedSocket;
    constructor(node: INode, socketName: string, shaderData: ShaderStandardInputData);
    /**
     * get the defaultValue of this socket
     */
    get defaultValue(): number[];
    /**
     * Get the class name of this socket
     */
    get className(): 'StandardInputSocket';
    /**
     * Get the glsl type of data to be passed between sockets
     */
    get socketType(): SocketTypeEnum;
    /**
     * Get the node that has the socket connected to this socket
     * @returns connected node or undefined
     */
    get connectedNode(): INode | undefined;
    /**
     * Get the socket that is connected to this socket
     * @returns connected socket or undefined
     */
    get connectedSocket(): IStandardOutputSocket | undefined;
    /**
     * Connect this socket and a standard output socket
     * @param outputSocket The output socket to connect to
     */
    connectSocketWith(outputSocket: IStandardOutputSocket): void;
    private __getDefaultValue;
}
