import AbstractSocket from '../abstract/AbstractSocket';
import { INode } from '../../node/INode';
import { ShaderUniformData } from '../../types/CommonType';
import { IUniformInputSocket } from '../interface/input/IUniformInputSocket';
/**
 * The UniformInputSocket is an input socket that receives an uniform variable.
 * If the function corresponding to a node uses an uniform variable,
 * the function must use this socket to receive the variable as an argument.
 */
export default class UniformInputSocket extends AbstractSocket implements IUniformInputSocket {
    private __variableName;
    private __type;
    private __precision?;
    constructor(node: INode, socketName: string, uniform: ShaderUniformData);
    /**
     * Get the class name of this socket
     */
    get className(): 'UniformInputSocket';
    /**
     * Get the uniform variable name
     */
    get variableName(): string;
    /**
     * Get the glsl type of uniform variable
     */
    get socketType(): import("shaderity/dist/esm/types/type").ShaderUniformVarTypeES3;
    /**
     * Get the precision of uniform variable
     */
    get precision(): import("shaderity/dist/esm/types/type").ShaderPrecisionType | undefined;
}
