import { INode } from '../../node/INode';
import { ShaderVaryingInputData } from '../../types/CommonType';
import { IVaryingOutputSocket } from '../interface/output/IVaryingOutputSocket';
import { IVaryingInputSocket } from '../interface/input/IVaryingInputSocket';
import AbstractSocket from '../abstract/AbstractSocket';
/**
 * The VaryingInputSocket is an input socket that receives an varying variable.
 * If the function corresponding to a node uses an varying variable,
 * the function must use this socket to receive the variable as an argument.
 * This socket can connects with VaryingOutputSockets.
 */
export default class VaryingInputSocket extends AbstractSocket implements IVaryingInputSocket {
    private __variableName;
    private __type;
    private __connectedSocket;
    constructor(node: INode, socketName: string, varying: ShaderVaryingInputData);
    /**
     * Get the class name of this socket
     */
    get className(): 'VaryingInputSocket';
    /**
     * Get the varying variable name
     */
    get variableName(): string;
    /**
     * Get the glsl type of varying variable
     */
    get socketType(): import("shaderity/dist/esm/types/type").ShaderAttributeVarType;
    /**
     * Get the interpolationType of varying variable(for GLSL ES3.0)
     */
    get interpolationType(): import("shaderity/dist/esm/types/type").ShaderVaryingInterpolationType | undefined;
    /**
     * Get the precision of varying variable
     */
    get precision(): import("shaderity/dist/esm/types/type").ShaderPrecisionType;
    /**
     * Get the node that has the socket connected to this socket
     * @returns connected node or undefined
     */
    get connectedNode(): INode | undefined;
    /**
     * Get the socket that is connected to this socket
     * @returns connected socket or undefined
     */
    get connectedSocket(): IVaryingOutputSocket | undefined;
    /**
     * Connect this socket and a varying output socket
     * @param outputSocket The output socket to connect to
     */
    connectSocketWith(outputSocket: IVaryingOutputSocket): void;
    /**
     * @private
     * change variable name of this socket
     */
    _setVariableName(newVariableName: string): void;
}
