import { INode } from '../../node/INode';
import { SamplerTypeEnum, SocketTypeEnum } from '../../types/CommonEnum';
import AbstractSocket from '../abstract/AbstractSocket';
import { ISamplerOutputSocket } from '../interface/output/ISamplerOutputSocket';
import { ISamplerInputSocket } from '../interface/input/ISamplerInputSocket';
import { IUniformInputSocket } from '../interface/input/IUniformInputSocket';
/**
 * The SamplerOutputSocket is an output socket that can connect to SamplerInputSockets.
 * This socket can connect to multiple SamplerInputSockets.
 */
export default class SamplerOutputSocket extends AbstractSocket implements ISamplerOutputSocket {
    private __connectedSockets;
    private __socketType;
    private __correspondingUniformInputSocket;
    constructor(node: INode, socketName: string, type: SamplerTypeEnum, correspondingUniformInputSocket: IUniformInputSocket);
    /**
     * Get the class name of this socket
     */
    get className(): 'SamplerOutputSocket';
    /**
     * Get the glsl type of data to be passed between sockets
     */
    get socketType(): SocketTypeEnum;
    /**
     * Get the nodes that have a socket connected to this socket.
     * @returns array of connected Nodes
     */
    get connectedNodes(): INode[];
    /**
     * Get the sockets that are connected to this socket.
     * @returns array of connected sockets
     */
    get connectedSockets(): ISamplerInputSocket[];
    get correspondingUniformInputSocket(): IUniformInputSocket;
    /**
     * @private
     * Connect socket from this socket to a sampler input socket
     * Do not call this method except from the connectSocketWith method of the SamplerInputSocket class
     *
     * @param inputSocket The input socket to connect to
     */
    _connectSocketWith(inputSocket: ISamplerInputSocket): void;
}
