import { IStandardOutputSocket } from '../interface/output/IStandardOutputSocket';
import { IStandardInputSocket } from '../interface/input/IStandardInputSocket';
import { INode } from '../../node/INode';
import { ShaderStandardOutputData } from '../../types/CommonType';
import { SocketTypeEnum } from '../../types/CommonEnum';
import AbstractSocket from '../abstract/AbstractSocket';
/**
 * The StandardOutputSocket is an output socket that can connect to StandardInputSockets.
 * This socket can connect to multiple StandardInputSockets.
 */
export default class StandardOutputSocket extends AbstractSocket implements IStandardOutputSocket {
    private __socketType;
    private __precision?;
    private __connectedSockets;
    constructor(node: INode, socketName: string, shaderData: ShaderStandardOutputData);
    /**
     * Get the class name of this socket
     */
    get className(): 'StandardOutputSocket';
    /**
     * Get the glsl type of data to be passed between sockets
     */
    get socketType(): SocketTypeEnum;
    /**
     * Get the precision of varying variable
     */
    get precision(): import("shaderity/dist/esm/types/type").ShaderPrecisionType | undefined;
    /**
     * Get the nodes that have a socket connected to this socket.
     * @returns array of connected Nodes
     */
    get connectedNodes(): INode[];
    /**
     * Get the sockets that are connected to this socket.
     * @returns array of connected sockets
     */
    get connectedSockets(): IStandardInputSocket[];
    /**
     * @private
     * Connect socket from this socket to a standard input socket
     * Do not call this method except from the connectSocketWith method of the StandardInputSocket class
     *
     * @param inputSocket The input socket to connect to
     */
    _connectSocketWith(inputSocket: IStandardInputSocket): void;
}
