import { INode } from '../../node/INode';
import { ShaderVaryingOutputData } from '../../types/CommonType';
import { IVaryingOutputSocket } from '../interface/output/IVaryingOutputSocket';
import { IVaryingInputSocket } from '../interface/input/IVaryingInputSocket';
import AbstractSocket from '../abstract/AbstractSocket';
/**
 * The VaryingOutputSocket is an output socket that sets a value to a varying variable.
 * This socket can connects with VaryingInputSockets.
 * This socket can be used only with vertex shader nodes.
 */
export default class VaryingOutputSocket extends AbstractSocket implements IVaryingOutputSocket {
    private __variableName;
    private __type;
    private __precision?;
    private __interpolationType;
    private __connectedSockets;
    constructor(node: INode, socketName: string, varying: ShaderVaryingOutputData);
    /**
     * Get the class name of this socket
     */
    get className(): 'VaryingOutputSocket';
    /**
     * Get the varying variable name
     */
    get variableName(): string;
    /**
     * Get the glsl type of varying variable
     */
    get socketType(): import("shaderity/dist/esm/types/type").ShaderAttributeVarType;
    /**
     * Get the interpolationType of varying variable(for GLSL ES3.0)
     */
    get interpolationType(): import("shaderity/dist/esm/types/type").ShaderVaryingInterpolationType | undefined;
    /**
     * Get the precision of varying variable
     */
    get precision(): import("shaderity/dist/esm/types/type").ShaderPrecisionType | undefined;
    /**
     * Get the nodes that have a socket connected to this socket.
     * @returns array of connected Nodes
     */
    get connectedNodes(): INode[];
    /**
     * Get the sockets that are connected to this socket.
     * @returns array of connected sockets
     */
    get connectedSockets(): IVaryingInputSocket[];
    /**
     * @private
     * Connect socket from this socket to a varying input socket
     * Do not call this method except from the connectSocketWith method of the VaryingInputSocket class
     *
     * @param inputSocket The input socket to connect to
     */
    _connectSocketWith(inputSocket: IVaryingInputSocket): void;
}
